Package: covRNA
Type: Package
Title: Multivariate Analysis of Transcriptomic Data
Version: 1.38.0
Author: Lara Urban <lara.h.urban@ebi.ac.uk>
Maintainer: Lara Urban <lara.h.urban@ebi.ac.uk>
Description: This package provides the analysis methods fourthcorner and RLQ
    analysis for large-scale transcriptomic data.
License: GPL (>= 2)
LazyData: TRUE
Depends: ade4, Biobase
Imports: parallel, genefilter, grDevices, stats, graphics
biocViews: GeneExpression, Transcription
Suggests: BiocStyle, knitr, rmarkdown
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/covRNA
git_branch: RELEASE_3_23
git_last_commit: 84cc5ca
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-28 21:48:16 UTC; biocbuild
Built: R 4.6.0; ; 2026-04-29 04:38:32 UTC; unix
