# import
import(parallel)
import(ade4)
import(Biobase)
import(genefilter)

import(grDevices)
import(stats)
importFrom("graphics","barplot","mtext","par","plot.default","rect","segments","strwidth","text")

# export
export(stat,ord,vis,plot.stat,plot.ord)

# S3methods
S3method(plot,stat)
S3method(plot,ord)

